package edu.nyu.scps.mediaplayerservice;

import android.app.Service;
import android.content.Intent;
import android.media.MediaPlayer;
import android.net.Uri;
import android.os.IBinder;
import android.widget.Toast;

import java.io.IOException;

public class MediaPlayerService extends Service {
    private MediaPlayer mediaPlayer;

    public MediaPlayerService() {
    }

    @Override
    public void onCreate() {
        super.onCreate();
        mediaPlayer = new MediaPlayer();
        Uri uri = Uri.parse("android.resource://" + getPackageName() + "/" + R.raw.musette);
        try {
            mediaPlayer.setDataSource(this, uri);
        } catch (IOException iOException) {
            Toast toast = Toast.makeText(MediaPlayerService.this, iOException.toString(), Toast.LENGTH_LONG);
            toast.show();
        }
        mediaPlayer.prepareAsync(); //will eventually call the onPrepared method of the OnPreparedListener

        mediaPlayer.setOnCompletionListener(new MediaPlayer.OnCompletionListener() {
            @Override
            public void onCompletion(MediaPlayer mediaPlayer) {
                Toast toast = Toast.makeText(MediaPlayerService.this, "complete", Toast.LENGTH_LONG);
                toast.show();
                MediaPlayerService.this.stopSelf();  //calls onDestroy, below
            }
        });
    }

    //called by the startService method of the Activity

    @Override
    public int onStartCommand(Intent intent, int flags, int startId) {
        mediaPlayer.setOnPreparedListener(new MediaPlayer.OnPreparedListener() {
            @Override
            public void onPrepared(MediaPlayer mp) {
                Toast toast = Toast.makeText(MediaPlayerService.this, "prepared", Toast.LENGTH_LONG);
                toast.show();
                mp.start();
            }
        });

        return super.onStartCommand(intent, flags, startId);
    }

    //called by stopSelf

    @Override
    public void onDestroy() {
        mediaPlayer.release();
        mediaPlayer = null;
        Toast toast = Toast.makeText(MediaPlayerService.this, "destroyed", Toast.LENGTH_LONG);
        toast.show();
        super.onDestroy();
    }

    @Override
    public IBinder onBind(Intent intent) {
        // TODO: Return the communication channel to the service.
        throw new UnsupportedOperationException("Not yet implemented");
    }
}
